<?php 

namespace FiloBlu\Esb\Setup;

class UpgradeData implements \Magento\Framework\Setup\UpgradeDataInterface
{
    /**
     * @var \Magento\Framework\DB\AggregatedFieldDataConverter
     */
    private $aggregatedFieldConverter;

    /**
     * @var \Magento\Framework\DB\Select\QueryModifierFactory
     */
    private $queryModifierFactory;

    /**
     * @var \Magento\Framework\DB\Query\Generator
     */
    private $queryGenerator;

    /**
     * Constructor
     *
     * @param \Magento\Framework\DB\AggregatedFieldDataConverter $aggregatedFieldConverter
     * @param \Magento\Framework\DB\Select\QueryModifierFactory $queryModifierFactory
     * @param \Magento\Framework\DB\Query\Generator $queryGenerator
     */
    public function __construct(
        \Magento\Framework\DB\AggregatedFieldDataConverter $aggregatedFieldConverter,
        \Magento\Framework\DB\Select\QueryModifierFactory $queryModifierFactory,
        \Magento\Framework\DB\Query\Generator $queryGenerator
    ) {
          $this->aggregatedFieldConverter = $aggregatedFieldConverter;
          $this->queryModifierFactory = $queryModifierFactory;
          $this->queryGenerator = $queryGenerator;
    }

    /**
     * {@inheritdoc}
     */
    public function upgrade(
        \Magento\Framework\Setup\ModuleDataSetupInterface $setup,
        \Magento\Framework\Setup\ModuleContextInterface $context
    ) {
          if (version_compare($context->getVersion(), '1.1.9', '<')) {
              $this->convertSerializedDataToJson($setup);
          }
    }

    /**
     * Upgrade to version 1.1.9, convert the configuration data
     * (oad/general/order_data_fields and oad/general/item_data_fields in core_config_data table).
     *
     * @param \Magento\Framework\Setup\ModuleDataSetupInterface $setup
     * @return void
     */
    private function convertSerializedDataToJson(\Magento\Framework\Setup\ModuleDataSetupInterface $setup)
    {
        
        // Convert data for the configuration
        $queryModifier = $this->queryModifierFactory->create(
            'in',
            [
                'values' => [
                    'path' => [
                        'esb/endpoints/events', 
                        'esb/ack/flows',
                        'esb/gwmapping/gwproducts'
                    ]
                ]
            ]
        );
        $fieldsToUpdate[] = new \Magento\Framework\DB\FieldToConvert(
            \Magento\Framework\DB\DataConverter\SerializedToJson::class,
            $setup->getTable('core_config_data'),
            'config_id',
            'value',
            $queryModifier
        );
        
        $this->aggregatedFieldConverter->convert($fieldsToUpdate, $setup->getConnection());
    }
    
}